// static/js/auth.js

import { handleApiError, updateAuthUI, setupLogout } from './utils.js';

document.addEventListener('DOMContentLoaded', () => {
    updateAuthUI();
    setupLogout();
    
    // Logowanie
    document.getElementById('loginForm')?.addEventListener('submit', async (e) => {
        e.preventDefault();
        
        try {
            const response = await fetch('/login', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({
                    email: document.getElementById('loginEmail').value,
                    haslo: document.getElementById('loginPassword').value
                })
            });

            if (response.ok) {
                const { token, imie } = await response.json();
                localStorage.setItem('token', token);
                localStorage.setItem('imie', imie);
                window.location.href = '/';
            } else {
                throw new Error('Błąd logowania!');
            }
        } catch (error) {
            handleApiError(error);
        }
    });
    
    // Rejestracja
    document.getElementById('registerForm')?.addEventListener('submit', async (e) => {
        e.preventDefault();
        const name = document.getElementById('registerName').value;
        const email = document.getElementById('registerEmail').value;
        const password = document.getElementById('registerPassword').value;
        const confirmPassword = document.getElementById('registerConfirmPassword').value;

        if (password !== confirmPassword) {
            alert('Hasła nie są identyczne');
            return;
        }

        try {
            const response = await fetch('/rejestracja', {
                method: 'POST',
                headers: { 'Content-Type': 'application/json' },
                body: JSON.stringify({ imie: name, email, haslo: password, confirmPassword }),
            });

            if (response.ok) {
                alert('Rejestracja udana! Możesz się teraz zalogować.');
                window.location.href = '/login.html';
            } else {
                throw new Error('Rejestracja nieudana');
            }
        } catch (error) {
            handleApiError(error);
        }
    });
});
